# AccelForge

AccelForge is a framework to model and design tensor algebra accelerators. To learn
more, see the [AccelForge website](https://accelergy-project.github.io/accelforge/). The
AccelForge source code is available on
[GitHub](https://github.com/Accelergy-Project/accelforge).

AccelForge uses [HWComponents](https://github.com/accelergy-project/hwcomponents)
as a backend to model the area, energy, latency, and leak power of hardware components.

## Installation

AccelForge is available on PyPI:

```bash
pip install accelforge
```

## Notebooks and Examples

Examples can be found in the [`notebooks`](notebooks) directory in the [AccelForge
repository](https://github.com/Accelergy-Project/accelforge). Examples of the input
files can be found in the [`examples`](examples) directory.
